@@ -19,111 +19,130 @@ from dkist_processing_test.tasks.write_l1 import WriteL1Data
 
 # TransferInputData Task
 transfer_input_data = Workflow(
-    process_category="test",
-    process_name="transfer_input_data",
+    input_data="input",
+    output_data="output",
+    category="test",
+    detail="transfer-input-data",
     workflow_package=__package__,
-    tags=["test"],
 )
 transfer_input_data.add_node(task=TransferL0Data, upstreams=None)
 
 # ParseInputData Task
 parse_input_data = Workflow(
-    process_category="test",
-    process_name="parse_input_data",
+    input_data="input",
+    output_data="output",
+    category="test",
+    detail="parse-input-data",
     workflow_package=__package__,
-    tags=["test"],
 )
 parse_input_data.add_node(task=ParseL0TestInputData, upstreams=None)
 
 # L0Quality Task
 quality_l0_metrics = Workflow(
-    process_category="test",
-    process_name="quality_l0_metrics",
+    input_data="input",
+    output_data="output",
+    category="test",
+    detail="quality-l0-metrics",
     workflow_package=__package__,
-    tags=["test"],
 )
 quality_l0_metrics.add_node(task=TestQualityL0Metrics, upstreams=None)
 
 # L1Quality Task
 quality_l1_metrics = Workflow(
-    process_category="test",
-    process_name="quality_l1_metrics",
+    input_data="input",
+    output_data="output",
+    category="test",
+    detail="quality-l1-metrics",
     workflow_package=__package__,
-    tags=["test"],
 )
 quality_l1_metrics.add_node(task=QualityL1Metrics, upstreams=None)
 
 # SubmitQuality Task
 quality_submit_metrics = Workflow(
-    process_category="test",
-    process_name="quality_submit_metrics",
+    input_data="input",
+    output_data="output",
+    category="test",
+    detail="quality-submit-metrics",
     workflow_package=__package__,
-    tags=["test"],
 )
 quality_submit_metrics.add_node(task=TestSubmitQuality, upstreams=None)
 
 # GenerateL1CalibratedData Task
 generate_calibrated_data = Workflow(
-    process_category="test",
-    process_name="generate_calibrated_data",
+    input_data="input",
+    output_data="output",
+    category="test",
+    detail="generate-calibrated-data",
     workflow_package=__package__,
-    tags=["test"],
 )
 generate_calibrated_data.add_node(task=GenerateCalibratedData, upstreams=None)
 
 # MakeTestMovieFrames task
 make_test_movie_frames = Workflow(
-    process_category="test",
-    process_name="make_test_movie_frames",
+    input_data="input",
+    output_data="output",
+    category="test",
+    detail="make-test-movie-frames",
     workflow_package=__package__,
-    tags=["test"],
 )
 make_test_movie_frames.add_node(task=MakeTestMovieFrames, upstreams=None)
 
 # AssembleTestMovie Task
 assemble_test_movie = Workflow(
-    process_category="test",
-    process_name="assemble_test_movie",
+    input_data="input",
+    output_data="output",
+    category="test",
+    detail="assemble-test-movie",
     workflow_package=__package__,
-    tags=["test"],
 )
 assemble_test_movie.add_node(task=AssembleTestMovie, upstreams=None)
 
 # WriteL1 Task
 write_l1 = Workflow(
-    process_category="test", process_name="write_l1", workflow_package=__package__, tags=["test"]
+    input_data="input",
+    output_data="output",
+    category="test",
+    detail="write-l1",
+    workflow_package=__package__,
 )
 write_l1.add_node(task=WriteL1Data, upstreams=None)
 
 # TransferOutputData Task
 transfer_output_data = Workflow(
-    process_category="test",
-    process_name="transfer_output_data",
+    input_data="input",
+    output_data="output",
+    category="test",
+    detail="transfer-output-data",
     workflow_package=__package__,
-    tags=["test"],
 )
 transfer_output_data.add_node(task=TransferL1Data, upstreams=None)
 
 # AddDatasetReceiptAccount Task
 add_dataset_receipt_account = Workflow(
-    process_category="test",
-    process_name="add_dataset_receipt_account",
+    input_data="input",
+    output_data="output",
+    category="test",
+    detail="add-dataset-receipt-account",
     workflow_package=__package__,
-    tags=["test"],
 )
 add_dataset_receipt_account.add_node(task=AddDatasetReceiptAccount, upstreams=None)
 
 # PublishCatalogMessages Task
 publish_catalog_messages = Workflow(
-    process_category="test",
-    process_name="publish_catalog_and_quality_messages",
+    input_data="input",
+    output_data="output",
+    category="test",
+    detail="publish-messages",
     workflow_package=__package__,
-    tags=["test"],
 )
 publish_catalog_messages.add_node(task=PublishCatalogAndQualityMessages, upstreams=None)
 
 # Teardown Task
 teardown = Workflow(
-    process_category="test", process_name="teardown", workflow_package=__package__, tags=["test"]
+    input_data="input",
+    output_data="output",
+    category="test",
+    detail="teardown",
+    workflow_package=__package__,
 )
 teardown.add_node(task=Teardown, upstreams=None)
